@@ -37,8 +37,8 @@ log = logging.getLogger("braille")
 import signal
 import os
 
-from gi.repository import GObject
-GObject.threads_init()
+from gi.repository import GLib
+GLib.threads_init()
 
 try:
     import louis
@@ -56,7 +56,7 @@ except:
     _brlAPIAvailable = False
     _brlAPIRunning = False
 
-import settings
+from . import settings
 
 try:
     # This can fail due to gtk not being available.  We want to
@@ -64,13 +64,15 @@ try:
     # for this is to allow "orca --text-setup" to work even if
     # the desktop is not running.
     #
-    import brlmon
+    from . import brlmon
 except:
     settings.enableBrailleMonitor = False
 
-import debug
-import eventsynthesizer
-import orca_state
+from . import brltablenames
+from . import cmdnames
+from . import debug
+from . import eventsynthesizer
+from . import orca_state
 
 # Right now, the orca autogen.sh/configure needs a priori knowledge of
 # where the liblouis tables are.  When running autogen.sh/configure,
@@ -81,7 +83,7 @@ import orca_state
 # liblouis bindings can give us the tablesdir information at runtime
 # http://code.google.com/p/liblouis/issues/detail?id=9]]
 #
-from orca_platform import tablesdir
+from .orca_platform import tablesdir
 if louis and not tablesdir:
     debug.println(debug.LEVEL_SEVERE,
                   "Contraction tables for liblouis cannot be found.")
@@ -93,8 +95,6 @@ if louis and not tablesdir:
                   "not be available.")
     louis = None
     
-from orca_i18n import _                          # for gettext support
-
 # The braille monitor
 #
 _monitor = None
@@ -112,89 +112,18 @@ if _brlAPIAvailable:
 command_name = {}
 
 if _brlAPIAvailable:
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, the display scrolls to the left.
-    #
-    command_name[brlapi.KEY_CMD_FWINLT]   = _("Line Left")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, the display scrolls to the right.
-    #
-    command_name[brlapi.KEY_CMD_FWINRT]   = _("Line Right")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, the display scrolls up.
-    #
-    command_name[brlapi.KEY_CMD_LNUP]     = _("Line Up")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, the display scrolls down.
-    #
-    command_name[brlapi.KEY_CMD_LNDN]     = _("Line Down")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, it instructs the braille display to freeze.
-    #
-    command_name[brlapi.KEY_CMD_FREEZE]     = _("Freeze")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, the display scrolls to the top left of the
-    # window.
-    #
-    command_name[brlapi.KEY_CMD_TOP_LEFT] = _("Top Left")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, the display scrolls to the bottom right of
-    # the window.
-    #
-    command_name[brlapi.KEY_CMD_BOT_LEFT] = _("Bottom Right")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, the display scrolls to position containing
-    # the cursor.
-    #
-    command_name[brlapi.KEY_CMD_HOME]     = _("Cursor Position")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # When pressing the button, the display toggles between contracted and
-    # contracted braille.
-    #
-    command_name[brlapi.KEY_CMD_SIXDOTS]  = _("Six Dots")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # This command represents a whole set of buttons known as cursor
-    # routings keys and are a way for a user to tell the machine they are
-    # interested in a particular character on the display.
-    #
-    command_name[brlapi.KEY_CMD_ROUTE]    = _("Cursor Routing")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # This command represents the start of a selection operation.  It is
-    # called "Cut Begin" to map to what BrlTTY users are used to:  in
-    # character cell mode operation on virtual consoles, the act of copying
-    # text is erroneously called a "cut" operation.
-    #
-    command_name[brlapi.KEY_CMD_CUTBEGIN] = _("Cut Begin")
-
-    # Translators: this is a command for a button on a refreshable braille
-    # display (an external hardware device used by people who are blind).
-    # This command represents marking the endpoint of a selection.  It is
-    # called "Cut Line" to map to what BrlTTY users are used to:  in
-    # character cell mode operation on virtual consoles, the act of copying
-    # text is erroneously called a "cut" operation.
-    #
-    command_name[brlapi.KEY_CMD_CUTLINE] = _("Cut Line")
+    command_name[brlapi.KEY_CMD_FWINLT]   = cmdnames.BRAILLE_LINE_LEFT
+    command_name[brlapi.KEY_CMD_FWINRT]   = cmdnames.BRAILLE_LINE_RIGHT
+    command_name[brlapi.KEY_CMD_LNUP]     = cmdnames.BRAILLE_LINE_UP
+    command_name[brlapi.KEY_CMD_LNDN]     = cmdnames.BRAILLE_LINE_DOWN
+    command_name[brlapi.KEY_CMD_FREEZE]   = cmdnames.BRAILLE_FREEZE
+    command_name[brlapi.KEY_CMD_TOP_LEFT] = cmdnames.BRAILLE_TOP_LEFT
+    command_name[brlapi.KEY_CMD_BOT_LEFT] = cmdnames.BRAILLE_BOTTOM_LEFT
+    command_name[brlapi.KEY_CMD_HOME]     = cmdnames.BRAILLE_HOME
+    command_name[brlapi.KEY_CMD_SIXDOTS]  = cmdnames.BRAILLE_SIX_DOTS
+    command_name[brlapi.KEY_CMD_ROUTE]    = cmdnames.BRAILLE_ROUTE_CURSOR
+    command_name[brlapi.KEY_CMD_CUTBEGIN] = cmdnames.BRAILLE_CUT_BEGIN
+    command_name[brlapi.KEY_CMD_CUTLINE]  = cmdnames.BRAILLE_CUT_LINE
 
 # The size of the physical display (width, height).  The coordinate system of
 # the display is set such that the upper left is (0,0), x values increase from
@@ -260,35 +189,37 @@ _saved = None
 # languages. You could read about braille tables at:
 # http://en.wikipedia.org/wiki/Braille
 #
-TABLE_NAMES = {"Cz-Cz-g1": _("Czech Grade 1"),
-               "Es-Es-g1": _("Spanish Grade 1"),
-               "Fr-Ca-g2": _("Canada French Grade 2"),
-               "Fr-Fr-g2": _("France French Grade 2"),
-               "Lv-Lv-g1": _("Latvian Grade 1"),
-               "Nl-Nl-g1": _("Netherlands Dutch Grade 1"),
-               "No-No-g0": _("Norwegian Grade 0"),
-               "No-No-g1": _("Norwegian Grade 1"),
-               "No-No-g2": _("Norwegian Grade 2"),
-               "No-No-g3": _("Norwegian Grade 3"),
-               "Pl-Pl-g1": _("Polish Grade 1"),
-               "Pt-Pt-g1": _("Portuguese Grade 1"),
-               "Se-Se-g1": _("Swedish Grade 1"),
-               "ar-ar-g1": _("Arabic Grade 1"),
-               "cy-cy-g1": _("Welsh Grade 1"),
-               "cy-cy-g2": _("Welsh Grade 2"),
-               "de-de-g0": _("German Grade 0"),
-               "de-de-g1": _("German Grade 1"),
-               "de-de-g2": _("German Grade 2"),
-               "en-GB-g2": _("U.K. English Grade 2"),
-               "en-gb-g1": _("U.K. English Grade 1"),
-               "en-us-g1": _("U.S. English Grade 1"),
-               "en-us-g2": _("U.S. English Grade 2"),
-               "fr-ca-g1": _("Canada French Grade 1"),
-               "fr-fr-g1": _("France French Grade 1"),
-               "gr-gr-g1": _("Greek Grade 1"),
-               "hi-in-g1": _("Hindi Grade 1"),
-               "it-it-g1": _("Italian Grade 1"),
-               "nl-be-g1": _("Belgium Dutch Grade 1")}
+TABLE_NAMES = {"Cz-Cz-g1": brltablenames.CZ_CZ_G1,
+               "Es-Es-g1": brltablenames.ES_ES_G1,
+               "Fr-Ca-g2": brltablenames.FR_CA_G2,
+               "Fr-Fr-g2": brltablenames.FR_FR_G2,
+               "Lv-Lv-g1": brltablenames.LV_LV_G1,
+               "Nl-Nl-g1": brltablenames.NL_NL_G1,
+               "No-No-g0": brltablenames.NO_NO_G0,
+               "No-No-g1": brltablenames.NO_NO_G1,
+               "No-No-g2": brltablenames.NO_NO_G2,
+               "No-No-g3": brltablenames.NO_NO_G3,
+               "Pl-Pl-g1": brltablenames.PL_PL_G1,
+               "Pt-Pt-g1": brltablenames.PT_PT_G1,
+               "Se-Se-g1": brltablenames.SE_SE_G1,
+               "ar-ar-g1": brltablenames.AR_AR_G1,
+               "cy-cy-g1": brltablenames.CY_CY_G1,
+               "cy-cy-g2": brltablenames.CY_CY_G2,
+               "de-de-g0": brltablenames.DE_DE_G0,
+               "de-de-g1": brltablenames.DE_DE_G1,
+               "de-de-g2": brltablenames.DE_DE_G2,
+               "en-GB-g2": brltablenames.EN_GB_G2,
+               "en-gb-g1": brltablenames.EN_GB_G1,
+               "en-us-g1": brltablenames.EN_US_G1,
+               "en-us-g2": brltablenames.EN_US_G2,
+               "fr-ca-g1": brltablenames.FR_CA_G1,
+               "fr-fr-g1": brltablenames.FR_FR_G1,
+               "gr-gr-g1": brltablenames.GR_GR_G1,
+               "hi-in-g1": brltablenames.HI_IN_G1,
+               "hu-hu-comp8": brltablenames.HU_HU_8DOT,
+               "hu-hu-g1": brltablenames.HU_HU_G1,
+               "it-it-g1": brltablenames.IT_IT_G1,
+               "nl-be-g1": brltablenames.NL_BE_G1}
 
 def listTables():
     tables = {}
@@ -353,11 +284,6 @@ class Region:
 
         self.expandOnCursor = expandOnCursor
 
-        try:
-            string = string.decode("UTF-8")
-        except UnicodeEncodeError:
-            pass
-
         # The uncontracted string for the line.
         #
         self.rawLine = string.strip("\n")
@@ -397,7 +323,7 @@ class Region:
 
         # Double check for ellipses.
         #
-        maskSize = len(self.string) + (2 * self.string.count(u'\u2026'))
+        maskSize = len(self.string) + (2 * self.string.count('\u2026'))
 
         # Create an empty mask.
         #
@@ -609,21 +535,6 @@ class Text(Region):
             self.caretOffset = 0
             self.lineOffset = 0
 
-        try:
-            string = string.decode("UTF-8")
-        except UnicodeEncodeError:
-            pass
-        if label:
-            try:
-                label = label.decode("UTF-8")
-            except UnicodeEncodeError:
-                pass
-        if eol:
-            try:
-                eol = eol.decode("UTF-8")
-            except UnicodeEncodeError:
-                pass
-
         try:
             endOffset = endOffset - self.lineOffset
         except TypeError:
@@ -676,7 +587,6 @@ class Text(Region):
         [string, caretOffset, lineOffset] = \
                  orca_state.activeScript.getTextLineAtCaret(self.accessible,
                                                             self.startOffset)
-        string = string.decode("UTF-8")
 
         cursorOffset = min(caretOffset - lineOffset, len(string))
 
@@ -764,7 +674,7 @@ class Text(Region):
             while n < nLinks:
                 link = hyperText.getLink(n)
                 if self.lineOffset <= link.startIndex:
-                    for i in xrange(link.startIndex, link.endIndex):
+                    for i in range(link.startIndex, link.endIndex):
                         try:
                             regionMask[i] |= linkIndicator
                         except:
@@ -792,7 +702,7 @@ class Text(Region):
                 if mask != settings.TEXT_ATTR_BRAILLE_NONE:
                     maskStart = max(startOffset - self.lineOffset, 0)
                     maskEnd = min(endOffset - self.lineOffset, stringLength)
-                    for i in xrange(maskStart, maskEnd):
+                    for i in range(maskStart, maskEnd):
                         regionMask[i] |= attrIndicator
 
         if selIndicator:
@@ -800,7 +710,7 @@ class Text(Region):
             for startOffset, endOffset in selections:
                 maskStart = max(startOffset - self.lineOffset, 0)
                 maskEnd = min(endOffset - self.lineOffset, stringLength)
-                for i in xrange(maskStart, maskEnd):
+                for i in range(maskStart, maskEnd):
                     regionMask[i] |= selIndicator
 
         if self.contracted:
@@ -949,7 +859,7 @@ class Line:
                 # The ultimate solution is to get i18n support into
                 # BrlTTY.]]]
                 #
-                string += region.string.replace(u'\u2026', "...")
+                string += region.string.replace('\u2026', "...")
             mask = region.getAttributeMask(getLinkMask)
             attributeMask += mask
 
@@ -1383,21 +1293,11 @@ def refresh(panToCursor=True,
         cursorCell += 1 # Normalize to 1-based offset
 
     logLine = "BRAILLE LINE:  '%s'" % string
-    try:
-        logLine = logLine.encode("UTF-8")
-    except UnicodeDecodeError:
-        pass
-
     debug.println(debug.LEVEL_INFO, logLine)
     log.info(logLine)
 
     logLine = "     VISIBLE:  '%s', cursor=%d" % \
                     (string[startPos:endPos], cursorCell)
-    try:
-        logLine = logLine.encode("UTF-8")
-    except UnicodeDecodeError:
-        pass
-
     debug.println(debug.LEVEL_INFO, logLine)
     log.info(logLine)
 
@@ -1413,7 +1313,7 @@ def refresh(panToCursor=True,
             if attributeMask:
                 attributeMask += '\x00'
             writeStruct.regionSize += 1
-        writeStruct.text = substring
+        writeStruct.text = bytes(substring, 'UTF-8')
         writeStruct.cursor = cursorCell
 
         # [[[WDW - if you want to muck around with the dots on the
@@ -1432,7 +1332,7 @@ def refresh(panToCursor=True,
         #writeStruct.attrOr = myUnderline
 
         if attributeMask:
-            writeStruct.attrOr = attributeMask[startPos:endPos]
+            writeStruct.attrOr = bytes(attributeMask[startPos:endPos], 'UTF-8')
 
         if not _brlAPIRunning:
             init(_callback, settings.tty)
@@ -1496,7 +1396,7 @@ def killFlash(restoreSaved=True):
     global viewport
     if _flashEventSourceId:
         if _flashEventSourceId > 0:
-            GObject.source_remove(_flashEventSourceId)
+            GLib.source_remove(_flashEventSourceId)
         if restoreSaved:
             (_lines, _regionWithFocus, viewport, flashTime) = _saved
             refresh(panToCursor=False, stopFlash=False)
@@ -1505,9 +1405,9 @@ def killFlash(restoreSaved=True):
 def resetFlashTimer():
     global _flashEventSourceId
     if _flashEventSourceId > 0:
-        GObject.source_remove(_flashEventSourceId)
+        GLib.source_remove(_flashEventSourceId)
         flashTime = _saved[3]
-        _flashEventSourceId = GObject.timeout_add(flashTime, _flashCallback)
+        _flashEventSourceId = GLib.timeout_add(flashTime, _flashCallback)
 
 def _initFlash(flashTime):
     """Sets up the state needed to flash a message or clears any existing
@@ -1526,13 +1426,13 @@ def _initFlash(flashTime):
 
     if _flashEventSourceId:
         if _flashEventSourceId > 0:
-            GObject.source_remove(_flashEventSourceId)
+            GLib.source_remove(_flashEventSourceId)
         _flashEventSourceId = 0
     else:
         _saved = (_lines, _regionWithFocus, viewport, flashTime)
 
     if flashTime > 0:
-        _flashEventSourceId = GObject.timeout_add(flashTime, _flashCallback)
+        _flashEventSourceId = GLib.timeout_add(flashTime, _flashCallback)
     elif flashTime < 0:
         _flashEventSourceId = -666
 
@@ -1824,9 +1724,13 @@ def init(callback=None, tty=7):
             debug.println(\
                 debug.LEVEL_CONFIGURATION,
                 "Braille module has been initialized using tty=%d" % tty)
-        _brlAPISourceId = GObject.io_add_watch(_brlAPI.fileDescriptor,
-                                               GObject.IO_IN,
-                                               _brlAPIKeyReader)
+        _brlAPISourceId = GLib.io_add_watch(_brlAPI.fileDescriptor,
+                                            GLib.PRIORITY_DEFAULT,
+                                            GLib.IO_IN,
+                                            _brlAPIKeyReader)
+    except NameError:
+        debug.println(debug.LEVEL_CONFIGURATION, "BrlApi is not defined")
+        return False
     except:
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Could not initialize BrlTTY:")
@@ -1868,7 +1772,7 @@ def shutdown():
 
     if _brlAPIRunning:
         _brlAPIRunning = False
-        GObject.source_remove(_brlAPISourceId)
+        GLib.source_remove(_brlAPISourceId)
         _brlAPISourceId = 0
         try:
             _brlAPI.leaveTtyMode()
