@@ -23,13 +23,16 @@ maps to the gettext.gettext function.  This function will accept a
 string and return a localized string for that string.
 """
 
-import os       # to get localdir path
-import gettext  # to get gettext (i18n) support
+import gettext
+import imp
+import os
+import sys
 
 # Alias gettext.gettext to _ and gettext.ngettext to ngettext
 #
 _ = gettext.gettext
 ngettext = gettext.ngettext
+cgettext = gettext.gettext
 
 # Tell gettext where to find localized strings.
 #
@@ -45,8 +48,43 @@ gettext.textdomain("orca")
 
 def C_(ctx, s):
     """Provide qualified translatable strings via context."""
-    translated = gettext.gettext('%s\x04%s' % (ctx, s))
+    translated = cgettext('%s\x04%s' % (ctx, s))
     if '\x04' in translated:
         # no translation found, return input string
         return s
     return translated
+
+def setModuleLocale(moduleName, newLocale=None):
+    global _, ngettext, cgettext
+
+    try:
+        translation = gettext.translation('orca', localedir, languages=[newLocale])
+        _ = translation.gettext
+        ngettext = translation.ngettext
+        cgettext = translation.gettext
+    except:
+        _ = gettext.gettext
+        ngettext = gettext.ngettext
+        cgettext = gettext.gettext
+    module = sys.modules.get(moduleName)
+    if module:
+        imp.reload(module)
+
+def setLocaleForMessages(newLocale=None):
+    modules = ['orca.tutorialgenerator', 'orca.messages']
+    for module in modules:
+        setModuleLocale(module, newLocale)
+
+def setLocaleForNames(newLocale=None):
+    modules = ['orca.chnames', 'orca.keynames', 'orca.phonnames',
+               'orca.text_attribute_names', 'orca.object_properties',
+               'orca.cmdnames', 'orca.keybindings']
+    for module in modules:
+        setModuleLocale(module, newLocale)
+
+def setLocaleForGUI(newLocale=None):
+    modules = ['orca.orca_gtkbuilder', 'orca.orca_gui_prefs',
+               'orca.app_gui_prefs', 'orca.guilabels',
+               'orca.brltablenames']
+    for module in modules:
+        setModuleLocale(module, newLocale)
